# Generated by Django 3.0 on 2021-03-09 15:10

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ("django_geosource", "0020_auto_20201008_0851"),
        ("terra_layer", "0058_migrate_style"),
    ]

    operations = [
        migrations.AlterField(
            model_name="layer",
            name="main_field",
            field=models.ForeignKey(
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                related_name="is_main_of",
                to="django_geosource.Field",
            ),
        ),
    ]
