# Generated by Django 3.1.3 on 2020-11-03 13:42

import django.contrib.postgres.fields.jsonb
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ("terra_layer", "0056_auto_20201124_1037"),
    ]

    operations = [
        migrations.AddField(
            model_name="customstyle",
            name="style_config",
            field=django.contrib.postgres.fields.jsonb.JSONField(default=dict),
        ),
        migrations.AddField(
            model_name="layer",
            name="main_style",
            field=django.contrib.postgres.fields.jsonb.JSONField(default=dict),
        ),
        migrations.AlterField(
            model_name="customstyle",
            name="layer",
            field=models.ForeignKey(
                on_delete=django.db.models.deletion.CASCADE,
                related_name="extra_styles",
                to="terra_layer.layer",
            ),
        ),
    ]
