# Generated by Django 3.1.2 on 2020-10-22 10:00

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("terra_layer", "0052_auto_20201022_0959"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="layer",
            name="popup_enable",
        ),
        migrations.RemoveField(
            model_name="layer",
            name="popup_maxzoom",
        ),
        migrations.RemoveField(
            model_name="layer",
            name="popup_minzoom",
        ),
        migrations.RemoveField(
            model_name="layer",
            name="popup_template",
        ),
    ]
